<?PHP



/**
 * Settings form for eactivist.
 */
function e_activist_settings_form() {
  $form['e_activist_tokens'] = array(
    '#type' => 'textarea',
    '#title' => t('API Tokens'),
    '#default_value' => implode("\r", variable_get('e_activist_tokens', array())),
    '#description' => t('Enter the public keys for the accounts you would like to import campaigns from. One per line or comma separated.'),
  );
  $form['e_activist_service_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Service URL'),
    '#default_value' => variable_get('e_activist_service_url', 'https://e-activist.com'),
    '#description' => t('Enter the public keys for the accounts you would like to import campaigns from. One per line or comma separated.'),
  );

  $form = system_settings_form($form);
  array_unshift($form['#submit'], 'e_activist_settings_form_submit');
  return $form;
}

function e_activist_settings_form_submit(&$form, &$form_state){
  $form_state['values']['e_activist_tokens'] = preg_split('#\r|\n|,#i', $form_state['values']['e_activist_tokens'], -1, PREG_SPLIT_NO_EMPTY);
  $form_state['values']['e_activist_tokens'] = array_map('trim',$form_state['values']['e_activist_tokens']);
}


/**
 *  Manage which campaigns are synced
 */
function e_activist_manage_campaigns_form(){
  $form = array();
  
  $synced = variable_get('e_activist_campaigns', array());
  
  $header = array(
    'campaign_id' => t('Campaign ID'),
    'campaign' => t('Campaign Name'),
    'actions' => t('Actions')
  );
  $options = array();

	$keys = variable_get('e_activist_tokens', array());

  if($keys && count($keys)){
    foreach($keys as $key){
      $campaigns = e_activist_api_get_campaigns($key);
      foreach($campaigns as $campaign){
        $rowId = $campaign->clientId . '-' . $campaign->campaignId;
        $options[$rowId] = array(
          'campaign_id' => $campaign->campaignId,
          'campaign' => $campaign->campaignName,
          'actions' => ''
        );
        if($nid = e_activist_get_campaign_nid($campaign->clientId, $campaign->campaignId)){
          $options[$rowId]['actions'] = l('View', 'node/'. $nid) . ' | ' . l('Demo', 'node/'.$nid.'/demo') . ' | ' . l('Edit', 'node/'.$nid.'/edit');
        }
      }
    }

    $form['instructions'] = array(
      '#markup' => '<div class="form-item"><p>Select which campaigns you would like to import from your e-activist account. Once selected, campaigns will continue to be updated with any changes made to the campaign in e-activist whenever the cron runs.</p></div>'
    );

    $form['campaigns'] = array(
      '#type' => 'tableselect',
      '#header' => $header,
      '#options' => $options,
      '#default_value' => variable_get('campaigns_to_sync', array()),
      '#empty' => t('No campaigns found.')
    );

    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => 'Sync selected campaigns'
    );
  }else {
    drupal_set_message('No e-activist api keys found. Please add your api key on the ' . l('e-activist settings', 'admin/structure/e_activist/settings') . ' page.', 'warning');
  }

  return $form;
}


/**
 *  Submit handler for campaigns sync
 */
function e_activist_manage_campaigns_form_submit($form, &$form_state){
  $campaigns = array();
  foreach($form_state['values']['campaigns'] as $key => $value){
    if($value){
      $campaigns[$key] = $value;
    }
  }
  variable_set('campaigns_to_sync', $campaigns);
  drupal_set_message('Campaigns synced successfully');
  $batch = e_activist_campaigns_batch();
	batch_set($batch);
}

