<?PHP
/**
 *	Implementation of hook_node_info().
 */
function e_activist_node_info(){
	return array(
		'e_activist_campaign' => array(
			'name' => t('E-Activist campaign'),
			'base' => 'e_activist',
			'description' => t('A node representation of an E-Activist campaign'),
			'has_title' => true,
			'title_label' => t('Campaign title')
		)
	);
}

/**
 * Implements hook_form().
 */
function e_activist_form($node, $form_state){
	$form = node_content_form($node, $form_state);
	$form['e_activist'] = array(
		'#type' => 'fieldset',
		'#title' => t('E-Activist'),
		'#weight' => -2
	);
	$form['e_activist']['e_activist_client_id'] = array(
		'#type' => 'textfield',
		'#title' => t('Client ID'),
		'#default_value' => isset($node->e_activist_client_id) ? $node->e_activist_client_id : '',
	);
	$form['e_activist']['e_activist_campaign_id'] = array(
		'#type' => 'textfield',
		'#title' => t('Campaign ID'),
		'#default_value' => isset($node->e_activist_campaign_id) ? $node->e_activist_campaign_id : '',
	);
	if(isset($node->nid)){
		$form['e_activist']['e_activist_demo_mode'] = array(
			'#title' => 'Demo Mode',
			'#markup' => '<p>' . l('Click here to test this campaign in demo mode.', 'node/' . $node->nid . '/demo') . '</p>'
		);
	}
	return $form;
}

/**
 * Implements hook_validate().
 */
function e_activist_validate($node, $form, &$form_state){
	if($node->nid){
		$n = node_load($node->nid);
		if(isset($n->e_activist_campaign_info) && isset($n->e_activist_campaign_info->status)){
			if($node->status && $n->e_activist_campaign_info->status == 'New'){
				form_set_error('status', 'You cannot publish this node while the campaign is not live in E-activist.');
			}
		}
	}
}

/**
 * Implements hook_load().
 */
function e_activist_load($nodes){
	foreach($nodes as $nid => $node){
		$q = db_query('SELECT e_activist_client_id, e_activist_campaign_id, e_activist_campaign_info, e_activist_campaign_hash FROM {e_activist_campaign} WHERE nid = :nid AND vid= :vid', array(':nid' => $node->nid, ':vid' => $node->vid));
		
		if($obj = $q->fetchObject()){
		 
			if(isset($obj->e_activist_campaign_info)){
				$obj->e_activist_campaign_info = json_decode($obj->e_activist_campaign_info);
			}
			foreach($obj as $key => $value){
				$nodes[$nid]->$key = $value;
			}
		}
			
	}
	return $nodes;
}

/**
 * Implements hook_view().
 */
function e_activist_view($node, $view_mode){
	$vms = variable_get('e_activist_campaign_view_modes', array('full'));
	if(in_array($view_mode, $vms)){
		$node->content['e_activist'] = drupal_get_form('e_activist_campaign_form', $node);
	}	
	return $node;
}

/**
 * Implements hook_update().
 */
function e_activist_update($node){
	e_activist_campaign_save($node);
}

/**
 * Implements hook_insert().
 */
function e_activist_insert($node){
	e_activist_campaign_save($node);
}

function e_activist_delete($node){
	db_query('DELETE FROM {e_activist_campaign} where nid = :nid', array(':nid' => $node->nid));
}

/**
 * Implements hook_node_presave().
 */
function e_activist_node_presave($node){
	if($node->type == 'e_activist_campaign'){
		e_activist_campaign_sync($node);
	}
}

function e_activist_campaign_save($node){
	$obj = new stdClass;
	$obj->e_activist_client_id = $node->e_activist_client_id;
	$obj->e_activist_campaign_id = $node->e_activist_campaign_id;
	$obj->e_activist_campaign_info = json_encode($node->e_activist_campaign_info);
	$obj->e_activist_campaign_hash = md5($obj->e_activist_campaign_info);
	$obj->nid = $node->nid;
	$obj->vid = $node->vid;

	db_query('DELETE FROM {e_activist_campaign} WHERE nid = :nid AND vid = :vid', array(':nid' => $node->nid, ':vid' => $node->vid));

	drupal_write_record('e_activist_campaign', $obj);
}

function e_activist_campaign_sync($node){
	if($campaign_info = e_activist_api_get_campaign($node->e_activist_campaign_id, $node->e_activist_client_id)){
		unset($campaign_info->sessionId);
		$node->e_activist_campaign_info = $campaign_info;
		$node->title = $campaign_info->name;
	}
}

function e_activist_get_campaign_node($client_id, $campaign_id){
	if($nid = e_activist_get_campaign_nid($client_id, $campaign_id)){
		return node_load($nid);
	}
	// node doesn't yet exist
	$node = new stdClass;
	$node->type = 'e_activist_campaign';
	$node->status = 0;
	$node->uid = 1;
	$node->e_activist_client_id = $client_id;
	$node->e_activist_campaign_id = $campaign_id;
	node_object_prepare($node);
	
	return $node;
}

function e_activist_get_campaign_nid($client_id, $campaign_id){
	$q = db_query('SELECT nid FROM e_activist_campaign WHERE e_activist_client_id = :client AND e_activist_campaign_id = :campaign', array(':client' => $client_id, ':campaign' => $campaign_id));
	if($nid = $q->fetchColumn()){
		return $nid;
	}
  return false;
}
